# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/whisper_normalizer',
                'doc_host': 'https://kurianbenoy.github.io',
                'git_url': 'https://github.com/kurianbenoy/whisper_normalizer',
                'lib_path': 'whisper_normalizer'},
  'syms': { 'whisper_normalizer.basic': { 'whisper_normalizer.basic.BasicTextNormalizer': ( 'basic.html#basictextnormalizer',
                                                                                            'whisper_normalizer/basic.py'),
                                          'whisper_normalizer.basic.BasicTextNormalizer.__call__': ( 'basic.html#basictextnormalizer.__call__',
                                                                                                     'whisper_normalizer/basic.py'),
                                          'whisper_normalizer.basic.BasicTextNormalizer.__init__': ( 'basic.html#basictextnormalizer.__init__',
                                                                                                     'whisper_normalizer/basic.py'),
                                          'whisper_normalizer.basic.remove_symbols': ( 'basic.html#remove_symbols',
                                                                                       'whisper_normalizer/basic.py'),
                                          'whisper_normalizer.basic.remove_symbols_and_diacritics': ( 'basic.html#remove_symbols_and_diacritics',
                                                                                                      'whisper_normalizer/basic.py')},
            'whisper_normalizer.core': {'whisper_normalizer.core.foo': ('core.html#foo', 'whisper_normalizer/core.py')},
            'whisper_normalizer.english': { 'whisper_normalizer.english.EnglishNumberNormalizer': ( 'english.html#englishnumbernormalizer',
                                                                                                    'whisper_normalizer/english.py'),
                                            'whisper_normalizer.english.EnglishNumberNormalizer.__call__': ( 'english.html#englishnumbernormalizer.__call__',
                                                                                                             'whisper_normalizer/english.py'),
                                            'whisper_normalizer.english.EnglishNumberNormalizer.__init__': ( 'english.html#englishnumbernormalizer.__init__',
                                                                                                             'whisper_normalizer/english.py'),
                                            'whisper_normalizer.english.EnglishNumberNormalizer.postprocess': ( 'english.html#englishnumbernormalizer.postprocess',
                                                                                                                'whisper_normalizer/english.py'),
                                            'whisper_normalizer.english.EnglishNumberNormalizer.preprocess': ( 'english.html#englishnumbernormalizer.preprocess',
                                                                                                               'whisper_normalizer/english.py'),
                                            'whisper_normalizer.english.EnglishNumberNormalizer.process_words': ( 'english.html#englishnumbernormalizer.process_words',
                                                                                                                  'whisper_normalizer/english.py'),
                                            'whisper_normalizer.english.EnglishSpellingNormalizer': ( 'english.html#englishspellingnormalizer',
                                                                                                      'whisper_normalizer/english.py'),
                                            'whisper_normalizer.english.EnglishSpellingNormalizer.__call__': ( 'english.html#englishspellingnormalizer.__call__',
                                                                                                               'whisper_normalizer/english.py'),
                                            'whisper_normalizer.english.EnglishSpellingNormalizer.__init__': ( 'english.html#englishspellingnormalizer.__init__',
                                                                                                               'whisper_normalizer/english.py'),
                                            'whisper_normalizer.english.EnglishTextNormalizer': ( 'english.html#englishtextnormalizer',
                                                                                                  'whisper_normalizer/english.py'),
                                            'whisper_normalizer.english.EnglishTextNormalizer.__call__': ( 'english.html#englishtextnormalizer.__call__',
                                                                                                           'whisper_normalizer/english.py'),
                                            'whisper_normalizer.english.EnglishTextNormalizer.__init__': ( 'english.html#englishtextnormalizer.__init__',
                                                                                                           'whisper_normalizer/english.py')},
            'whisper_normalizer.indic': { 'whisper_normalizer.indic.BaseNormalizer': ( '1b.indic_normalizer.html#basenormalizer',
                                                                                       'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.BaseNormalizer.__init__': ( '1b.indic_normalizer.html#basenormalizer.__init__',
                                                                                                'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.BaseNormalizer._init_normalize_chandras': ( '1b.indic_normalizer.html#basenormalizer._init_normalize_chandras',
                                                                                                                'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.BaseNormalizer._init_normalize_nasals': ( '1b.indic_normalizer.html#basenormalizer._init_normalize_nasals',
                                                                                                              'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.BaseNormalizer._init_normalize_vowel_ending': ( '1b.indic_normalizer.html#basenormalizer._init_normalize_vowel_ending',
                                                                                                                    'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.BaseNormalizer._init_to_anusvaara_relaxed': ( '1b.indic_normalizer.html#basenormalizer._init_to_anusvaara_relaxed',
                                                                                                                  'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.BaseNormalizer._init_to_anusvaara_strict': ( '1b.indic_normalizer.html#basenormalizer._init_to_anusvaara_strict',
                                                                                                                 'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.BaseNormalizer._init_to_nasal_consonants': ( '1b.indic_normalizer.html#basenormalizer._init_to_nasal_consonants',
                                                                                                                 'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.BaseNormalizer._normalize_chandras': ( '1b.indic_normalizer.html#basenormalizer._normalize_chandras',
                                                                                                           'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.BaseNormalizer._normalize_nasals': ( '1b.indic_normalizer.html#basenormalizer._normalize_nasals',
                                                                                                         'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.BaseNormalizer._normalize_vowel_ending': ( '1b.indic_normalizer.html#basenormalizer._normalize_vowel_ending',
                                                                                                               'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.BaseNormalizer._normalize_word_vowel_ending_dravidian': ( '1b.indic_normalizer.html#basenormalizer._normalize_word_vowel_ending_dravidian',
                                                                                                                              'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.BaseNormalizer._normalize_word_vowel_ending_ie': ( '1b.indic_normalizer.html#basenormalizer._normalize_word_vowel_ending_ie',
                                                                                                                       'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.BaseNormalizer._to_anusvaara_relaxed': ( '1b.indic_normalizer.html#basenormalizer._to_anusvaara_relaxed',
                                                                                                             'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.BaseNormalizer._to_anusvaara_strict': ( '1b.indic_normalizer.html#basenormalizer._to_anusvaara_strict',
                                                                                                            'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.BaseNormalizer._to_nasal_consonants': ( '1b.indic_normalizer.html#basenormalizer._to_nasal_consonants',
                                                                                                            'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.BaseNormalizer.correct_visarga': ( '1b.indic_normalizer.html#basenormalizer.correct_visarga',
                                                                                                       'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.BaseNormalizer.get_char_stats': ( '1b.indic_normalizer.html#basenormalizer.get_char_stats',
                                                                                                      'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.BaseNormalizer.normalize': ( '1b.indic_normalizer.html#basenormalizer.normalize',
                                                                                                 'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.BengaliNormalizer': ( '1b.indic_normalizer.html#bengalinormalizer',
                                                                                          'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.BengaliNormalizer.__call__': ( '1b.indic_normalizer.html#bengalinormalizer.__call__',
                                                                                                   'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.BengaliNormalizer.__init__': ( '1b.indic_normalizer.html#bengalinormalizer.__init__',
                                                                                                   'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.DevanagariNormalizer': ( '1b.indic_normalizer.html#devanagarinormalizer',
                                                                                             'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.DevanagariNormalizer.__call__': ( '1b.indic_normalizer.html#devanagarinormalizer.__call__',
                                                                                                      'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.DevanagariNormalizer.__init__': ( '1b.indic_normalizer.html#devanagarinormalizer.__init__',
                                                                                                      'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.DevanagariNormalizer.get_char_stats': ( '1b.indic_normalizer.html#devanagarinormalizer.get_char_stats',
                                                                                                            'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.GujaratiNormalizer': ( '1b.indic_normalizer.html#gujaratinormalizer',
                                                                                           'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.GujaratiNormalizer.__call__': ( '1b.indic_normalizer.html#gujaratinormalizer.__call__',
                                                                                                    'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.GujaratiNormalizer.__init__': ( '1b.indic_normalizer.html#gujaratinormalizer.__init__',
                                                                                                    'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.HindiNormalizer': ( '1b.indic_normalizer.html#hindinormalizer',
                                                                                        'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.HindiNormalizer.__call__': ( '1b.indic_normalizer.html#hindinormalizer.__call__',
                                                                                                 'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.HindiNormalizer.__init__': ( '1b.indic_normalizer.html#hindinormalizer.__init__',
                                                                                                 'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.KannadaNormalizer': ( '1b.indic_normalizer.html#kannadanormalizer',
                                                                                          'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.KannadaNormalizer.__call__': ( '1b.indic_normalizer.html#kannadanormalizer.__call__',
                                                                                                   'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.KannadaNormalizer.__init__': ( '1b.indic_normalizer.html#kannadanormalizer.__init__',
                                                                                                   'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.MalayalamNormalizer': ( '1b.indic_normalizer.html#malayalamnormalizer',
                                                                                            'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.MalayalamNormalizer.__call__': ( '1b.indic_normalizer.html#malayalamnormalizer.__call__',
                                                                                                     'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.MalayalamNormalizer.__init__': ( '1b.indic_normalizer.html#malayalamnormalizer.__init__',
                                                                                                     'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.MalayalamNormalizer._canonicalize_chillus': ( '1b.indic_normalizer.html#malayalamnormalizer._canonicalize_chillus',
                                                                                                                  'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.MalayalamNormalizer._correct_geminated_T': ( '1b.indic_normalizer.html#malayalamnormalizer._correct_geminated_t',
                                                                                                                 'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.NormalizerI': ( '1b.indic_normalizer.html#normalizeri',
                                                                                    'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.NormalizerI._normalize_punctuations': ( '1b.indic_normalizer.html#normalizeri._normalize_punctuations',
                                                                                                            'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.NormalizerI.normalize': ( '1b.indic_normalizer.html#normalizeri.normalize',
                                                                                              'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.OdiaNormalizer': ( '1b.indic_normalizer.html#odianormalizer',
                                                                                       'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.OdiaNormalizer.__call__': ( '1b.indic_normalizer.html#odianormalizer.__call__',
                                                                                                'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.OdiaNormalizer.__init__': ( '1b.indic_normalizer.html#odianormalizer.__init__',
                                                                                                'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.PunjabiNormalizer': ( '1b.indic_normalizer.html#punjabinormalizer',
                                                                                          'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.PunjabiNormalizer.__call__': ( '1b.indic_normalizer.html#punjabinormalizer.__call__',
                                                                                                   'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.PunjabiNormalizer.__init__': ( '1b.indic_normalizer.html#punjabinormalizer.__init__',
                                                                                                   'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.PunjabiNormalizer._normalize_vowels': ( '1b.indic_normalizer.html#punjabinormalizer._normalize_vowels',
                                                                                                            'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.TamilNormalizer': ( '1b.indic_normalizer.html#tamilnormalizer',
                                                                                        'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.TamilNormalizer.__call__': ( '1b.indic_normalizer.html#tamilnormalizer.__call__',
                                                                                                 'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.TamilNormalizer.__init__': ( '1b.indic_normalizer.html#tamilnormalizer.__init__',
                                                                                                 'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.TeluguNormalizer': ( '1b.indic_normalizer.html#telugunormalizer',
                                                                                         'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.TeluguNormalizer.__call__': ( '1b.indic_normalizer.html#telugunormalizer.__call__',
                                                                                                  'whisper_normalizer/indic.py'),
                                          'whisper_normalizer.indic.TeluguNormalizer.__init__': ( '1b.indic_normalizer.html#telugunormalizer.__init__',
                                                                                                  'whisper_normalizer/indic.py')},
            'whisper_normalizer.langinfo': { 'whisper_normalizer.langinfo.get_offset': ( '1a.langinfo.html#get_offset',
                                                                                         'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.in_coordinated_range': ( '1a.langinfo.html#in_coordinated_range',
                                                                                                   'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_approximant': ( '1a.langinfo.html#is_approximant',
                                                                                             'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_approximant_offset': ( '1a.langinfo.html#is_approximant_offset',
                                                                                                    'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_aspirated': ( '1a.langinfo.html#is_aspirated',
                                                                                           'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_aspirated_offset': ( '1a.langinfo.html#is_aspirated_offset',
                                                                                                  'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_aum': ( '1a.langinfo.html#is_aum',
                                                                                     'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_aum_offset': ( '1a.langinfo.html#is_aum_offset',
                                                                                            'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_consonant': ( '1a.langinfo.html#is_consonant',
                                                                                           'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_consonant_offset': ( '1a.langinfo.html#is_consonant_offset',
                                                                                                  'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_danda_delim': ( '1a.langinfo.html#is_danda_delim',
                                                                                             'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_dental': ( '1a.langinfo.html#is_dental',
                                                                                        'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_dental_offset': ( '1a.langinfo.html#is_dental_offset',
                                                                                               'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_fricative': ( '1a.langinfo.html#is_fricative',
                                                                                           'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_fricative_offset': ( '1a.langinfo.html#is_fricative_offset',
                                                                                                  'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_halanta': ( '1a.langinfo.html#is_halanta',
                                                                                         'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_halanta_offset': ( '1a.langinfo.html#is_halanta_offset',
                                                                                                'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_indiclang_char': ( '1a.langinfo.html#is_indiclang_char',
                                                                                                'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_labial': ( '1a.langinfo.html#is_labial',
                                                                                        'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_labial_offset': ( '1a.langinfo.html#is_labial_offset',
                                                                                               'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_nasal': ( '1a.langinfo.html#is_nasal',
                                                                                       'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_nasal_offset': ( '1a.langinfo.html#is_nasal_offset',
                                                                                              'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_nukta': ( '1a.langinfo.html#is_nukta',
                                                                                       'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_nukta_offset': ( '1a.langinfo.html#is_nukta_offset',
                                                                                              'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_number': ( '1a.langinfo.html#is_number',
                                                                                        'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_number_offset': ( '1a.langinfo.html#is_number_offset',
                                                                                               'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_palatal': ( '1a.langinfo.html#is_palatal',
                                                                                         'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_palatal_offset': ( '1a.langinfo.html#is_palatal_offset',
                                                                                                'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_retroflex': ( '1a.langinfo.html#is_retroflex',
                                                                                           'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_retroflex_offset': ( '1a.langinfo.html#is_retroflex_offset',
                                                                                                  'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_unaspirated': ( '1a.langinfo.html#is_unaspirated',
                                                                                             'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_unaspirated_offset': ( '1a.langinfo.html#is_unaspirated_offset',
                                                                                                    'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_unvoiced': ( '1a.langinfo.html#is_unvoiced',
                                                                                          'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_unvoiced_offset': ( '1a.langinfo.html#is_unvoiced_offset',
                                                                                                 'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_velar': ( '1a.langinfo.html#is_velar',
                                                                                       'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_velar_offset': ( '1a.langinfo.html#is_velar_offset',
                                                                                              'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_voiced': ( '1a.langinfo.html#is_voiced',
                                                                                        'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_voiced_offset': ( '1a.langinfo.html#is_voiced_offset',
                                                                                               'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_vowel': ( '1a.langinfo.html#is_vowel',
                                                                                       'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_vowel_offset': ( '1a.langinfo.html#is_vowel_offset',
                                                                                              'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_vowel_sign': ( '1a.langinfo.html#is_vowel_sign',
                                                                                            'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.is_vowel_sign_offset': ( '1a.langinfo.html#is_vowel_sign_offset',
                                                                                                   'whisper_normalizer/langinfo.py'),
                                             'whisper_normalizer.langinfo.offset_to_char': ( '1a.langinfo.html#offset_to_char',
                                                                                             'whisper_normalizer/langinfo.py')}}}
